summaryrefslogtreecommitdiff
path: root/boost/accumulators/numeric/functional/valarray.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'boost/accumulators/numeric/functional/valarray.hpp')
-rw-r--r--boost/accumulators/numeric/functional/valarray.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/boost/accumulators/numeric/functional/valarray.hpp b/boost/accumulators/numeric/functional/valarray.hpp
index 41766a0371..c24b45859d 100644
--- a/boost/accumulators/numeric/functional/valarray.hpp
+++ b/boost/accumulators/numeric/functional/valarray.hpp
@@ -234,9 +234,9 @@ namespace boost { namespace numeric
}
};
// partial specialization of numeric::average<> for std::valarray.
template<typename Left, typename Right, typename RightTag>
- struct average<Left, Right, std_valarray_tag, RightTag>
+ struct fdiv<Left, Right, std_valarray_tag, RightTag>
: mpl::if_<
are_integral<typename Left::value_type, Right>
, divides<Left, double const>
@@ -234,9 +234,9 @@ namespace boost { namespace numeric
}
};
- // partial specialization of numeric::average<> for std::valarray.
+ // partial specialization of numeric::fdiv<> for std::valarray.
template<typename Left, typename Right, typename RightTag>